@@ -1,5 +1,5 @@
 package File::Collector ;
-$File::Collector::VERSION = '0.032';
+$File::Collector::VERSION = '0.033';
 use strict; use warnings;
 
 use Carp;
@@ -351,7 +351,7 @@ sub _generate_short_names {
   if (@files) {
     foreach my $file ( @files, $file ) {
       my $tfile = $file;
-      $tfile =~ s/$longest_string//;
+      $tfile =~ s/\Q$longest_string\E//;
       $s->{_files}{all}{$file}{short_path} = $tfile;
     }
   } else {
@@ -428,7 +428,7 @@ File::Collector - Base class for custom File::Collector classes for classifying
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 OVERVIEW
 
